@@ -4,8 +4,11 @@ use warnings;
 use strict;
 
 use base 'DBIx::Custom';
+
 use Carp 'croak';
 
+__PACKAGE__->attr([qw/database host port/]);
+
 sub connect {
     my $proto = shift;
     
@@ -18,11 +21,9 @@ sub connect {
         my $host     = $self->host;
         my $port     = $self->port;
         my $data_source = "dbi:mysql:";
-        my $data_source_original = $data_source;
         $data_source .= "database=$database;" if $database;
         $data_source .= "host=$host;"         if $host;
         $data_source .= "port=$port;"         if $port;
-        $data_source =~ s/:$// if $data_source eq $data_source_original;
         $self->data_source($data_source);
     }
     
@@ -45,39 +46,69 @@ sub last_insert_id {
 
 =head1 NAME
 
-DBIx::Custom::MySQL - DBIx::Custom MySQL implementation
+DBIx::Custom::MySQL - a MySQL implementation of DBIx::Custom
 
 =head1 SYNOPSYS
 
-    # New
+    # Connect
     my $dbi = DBIx::Custom::MySQL->connect(user      => 'taro', 
-                                           $password => 'kliej&@K',
-                                           database  => 'sample_db');
+                                           password => 'kliej&@K',
+                                           database  => 'your_database');
+    
+    # Last insert id
+    my $id = $dbi->last_insert_id;
+
+=head1 ATTRIBUTES
+
+This class is L<DBIx::Custom> subclass.
+You can use all attributes of L<DBIx::Custom>
+
+=head2 database
+
+Database name
+
+    $dbi      = $dbi->database('your_database');
+    $database = $dbi->database;
+
+=head2 host
+
+Database host name.
+
+    $dbi  = $dbi->host('somehost.com');
+    $host = $dbi->host;
+
+IP address can be set to host attribute.
+
+    $dbi->host('127.03.45.12');
+
+=head2 port
+
+Database port.
+
+    $dbi  = $dbi->port(1198);
+    $port = $dbi->port;
 
 =head1 METHODS
 
-This class is L<DBIx::Custom::Basic> subclass.
-You can use all methods of L<DBIx::Custom::Basic>
+This class is L<DBIx::Custom> subclass.
+You can use all methods of L<DBIx::Custom>.
 
-=head2 connect
+=head2 connect - overridden
 
-Connect to database
+Connect to database.
 
-    $self->connect;
-
-If you set database, host, or port, data source is automatically created.
+    # Connect
+    my $dbi = DBIx::Custom::MySQL->connect(user      => 'taro', 
+                                           password => 'kliej&@K',
+                                           database  => 'your_database');
 
 =head2 last_insert_id
 
+Last insert ID.
+
     $last_insert_id = $dbi->last_insert_id;
 
-The folloing is last_insert_id sample.
+This is equal to MySQL last_insert_id() function.
 
-    $dbi->insert('books', {title => 'Perl', author => 'taro'});
-    $last_insert_id = $dbi->last_insert_id;
-
-This is equal to MySQL function
-
-    last_insert_id()
     
 =cut
